Index: binaries/data/mods/public/maps/random/aegean_sea.js
===================================================================
--- binaries/data/mods/public/maps/random/aegean_sea.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/aegean_sea.js	(working copy)
@@ -49,8 +49,6 @@
 // terrain + entity (for painting)
 const pForest = [tForestFloor, tForestFloor + TERRAIN_SEPARATOR + oCarob, tForestFloor + TERRAIN_SEPARATOR + oDatePalm, tForestFloor + TERRAIN_SEPARATOR + oSDatePalm, tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
 log("Initializing map...");
 
 InitMap();
@@ -135,7 +133,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/alpine_lakes.js
===================================================================
--- binaries/data/mods/public/maps/random/alpine_lakes.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/alpine_lakes.js	(working copy)
@@ -87,9 +87,7 @@
 
 //other constants
 const pForest = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
 log("Initializing map...");
 
 InitMap();
@@ -170,7 +168,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/alpine_valley.js
===================================================================
--- binaries/data/mods/public/maps/random/alpine_valley.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/alpine_valley.js	(working copy)
@@ -74,9 +74,7 @@
 
 //other constants
 const pForest = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
 log("Initializing map...");
 
 InitMap();
@@ -157,7 +155,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/anatolian_plateau.js
===================================================================
--- binaries/data/mods/public/maps/random/anatolian_plateau.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/anatolian_plateau.js	(working copy)
@@ -33,10 +33,7 @@
 const aBushSmall = "actor|props/flora/bush_medit_sm.xml";
 
 const pForest = [tForestFloor + TERRAIN_SEPARATOR + oPoplar, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -107,7 +104,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/archipelago.js
===================================================================
--- binaries/data/mods/public/maps/random/archipelago.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/archipelago.js	(working copy)
@@ -49,10 +49,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -127,7 +124,7 @@
 	createArea(placer, [terrainPainter, elevationPainter, paintClass(clPlayer)], null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/ardennes_forest.js
===================================================================
--- binaries/data/mods/public/maps/random/ardennes_forest.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/ardennes_forest.js	(working copy)
@@ -1,9 +1,5 @@
 RMS.LoadLibrary("rmgen");
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -177,7 +173,7 @@
 	var iz = round(fz);
 
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	var citySize = 250
 
Index: binaries/data/mods/public/maps/random/atlas_mountains.js
===================================================================
--- binaries/data/mods/public/maps/random/atlas_mountains.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/atlas_mountains.js	(working copy)
@@ -46,10 +46,6 @@
 const pForest1 = [tForestFloor + TERRAIN_SEPARATOR + oCarob, tForestFloor];
 const pForest2 = [tForestFloor + TERRAIN_SEPARATOR + oAleppoPine, tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -121,7 +117,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/belgian_uplands.js
===================================================================
--- binaries/data/mods/public/maps/random/belgian_uplands.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/belgian_uplands.js	(working copy)
@@ -6,10 +6,6 @@
 RMS.LoadLibrary("rmgen");
 RMS.LoadLibrary("heightmap");
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -419,14 +415,14 @@
 {
 	var actualX = possibleStartPositions[bestDerivation[p]][0];
 	var actualY = possibleStartPositions[bestDerivation[p]][1];
-	placeCivDefaultEntities(actualX, actualY, p + 1, BUILDING_ANGlE, {"iberWall" : false});
+	placeCivDefaultEntities(actualX, actualY, p + 1, { "iberWall": false });
 
 	// Place some start resources
 	var uDist = 8;
 	var uSpace = 1;
 	for (var j = 1; j <= 4; ++j)
 	{
-		var uAngle = BUILDING_ANGlE - PI * (2-j) / 2;
+		var uAngle = BUILDING_ORIENTATION - PI * (2-j) / 2;
 		var count = 4;
 		for (var numberofentities = 0; numberofentities < count; numberofentities++)
 		{
Index: binaries/data/mods/public/maps/random/cantabrian_highlands.js
===================================================================
--- binaries/data/mods/public/maps/random/cantabrian_highlands.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/cantabrian_highlands.js	(working copy)
@@ -47,10 +47,6 @@
 const pForestD = [tGrassDForest + TERRAIN_SEPARATOR + oOak, tGrassDForest + TERRAIN_SEPARATOR + oOakLarge, tGrassDForest];
 const pForestP = [tGrassPForest + TERRAIN_SEPARATOR + oPine, tGrassPForest + TERRAIN_SEPARATOR + oAleppoPine, tGrassPForest];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -145,7 +141,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : false});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': false });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/canyon.js
===================================================================
--- binaries/data/mods/public/maps/random/canyon.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/canyon.js	(working copy)
@@ -49,10 +49,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -156,7 +153,7 @@
 	createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/continent.js
===================================================================
--- binaries/data/mods/public/maps/random/continent.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/continent.js	(working copy)
@@ -46,10 +46,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -153,7 +150,7 @@
 	createArea(placer, [elevationPainter, paintClass(clLand)], null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/corinthian_isthmus.js
===================================================================
--- binaries/data/mods/public/maps/random/corinthian_isthmus.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/corinthian_isthmus.js	(working copy)
@@ -46,8 +46,6 @@
 // terrain + entity (for painting)
 const pForest = [tForestFloor, tForestFloor + TERRAIN_SEPARATOR + oCarob, tForestFloor + TERRAIN_SEPARATOR + oDatePalm, tForestFloor + TERRAIN_SEPARATOR + oSDatePalm, tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
 log("Initializing map...");
 
 InitMap();
@@ -182,7 +180,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/corsica.js
===================================================================
--- binaries/data/mods/public/maps/random/corsica.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/corsica.js	(working copy)
@@ -61,10 +61,6 @@
 var tForestNicaeLight = [tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + eFanPalm, tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor];
 var tForestNicaeScarce = [tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + eFanPalm, tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -336,7 +332,7 @@
 	createArea(placer, [painter,paintClass(clSettlement),elevationPainter], null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : false});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': false });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/cycladic_archipelago.js
===================================================================
--- binaries/data/mods/public/maps/random/cycladic_archipelago.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/cycladic_archipelago.js	(working copy)
@@ -70,10 +70,6 @@
 const pPoplarForest = [tForestFloor+TERRAIN_SEPARATOR+oLombardyPoplar, tGrass];
 const pMainForest = [tForestFloor+TERRAIN_SEPARATOR+oCarob, tForestFloor+TERRAIN_SEPARATOR+oBeech, tGrass, tGrass];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -284,7 +280,7 @@
 	createArea(placer, [painter,paintClass(clCity)], null);
 
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 
     nPlayer++;
 }
Index: binaries/data/mods/public/maps/random/deep_forest.js
===================================================================
--- binaries/data/mods/public/maps/random/deep_forest.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/deep_forest.js	(working copy)
@@ -58,7 +58,6 @@
 var baseRadius = 20;
 var minPlayerRadius = min(mapRadius-1.5*baseRadius, 5*mapRadius/8);
 var maxPlayerRadius = min(mapRadius-baseRadius, 3*mapRadius/4);
-const BUILDING_ANGlE = -PI/4;
 var playerStartLocX = new Array(numPlayers);
 var playerStartLocZ = new Array(numPlayers);
 var playerAngle = new Array(numPlayers);
@@ -96,7 +95,7 @@
 	playerStartLocX[i] = x;
 	playerStartLocZ[i] = z;
 	// Place starting entities
-	placeCivDefaultEntities(x, z, i+1, BUILDING_ANGlE);
+	placeCivDefaultEntities(x, z, i+1);
 	// Place base texture
 	var placer = new ClumpPlacer(2*baseRadius*baseRadius, 2/3, 1/8, 10, x, z);
 	var painter = [new LayeredPainter([terrainBaseBorder, terrainBase, terrainBaseCenter], [baseRadius/4, baseRadius/4]), paintClass(clPlayer)];
Index: binaries/data/mods/public/maps/random/english_channel.js
===================================================================
--- binaries/data/mods/public/maps/random/english_channel.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/english_channel.js	(working copy)
@@ -49,10 +49,6 @@
 
 const WATER_WIDTH = 0.25;
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -144,7 +140,7 @@
 	createArea(placer, [painter, paintClass(clPlayer)], null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/flood.js
===================================================================
--- binaries/data/mods/public/maps/random/flood.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/flood.js	(working copy)
@@ -47,7 +47,6 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
 log("Initializing map...");
 InitMap();
@@ -146,7 +145,7 @@
 	addToClass(ix - 5, iz, clPlayer);
 	addToClass(ix, iz - 5, clPlayer);
 
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, { "iberWall": false });
+	placeCivDefaultEntities(fx, fz, id, { "iberWall": false });
 
 	// Create the city patch
 	let cityRadius = radius/3;
Index: binaries/data/mods/public/maps/random/fortress.js
===================================================================
--- binaries/data/mods/public/maps/random/fortress.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/fortress.js	(working copy)
@@ -47,10 +47,6 @@
 const pForestO = [tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor];
 const pForestP = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -100,12 +96,12 @@
 {
 	var startEntities = getStartingEntities(i);
 	// Place starting entities
-	createStartingPlayerEntities(playerX[i], playerZ[i], i+1, startEntities, BUILDING_ANGlE)
+	createStartingPlayerEntities(playerX[i], playerZ[i], i+1, startEntities)
 	var uDist = 8;
 	var uSpace = 2;
 	for (var j = 1; j < startEntities.length - 1; ++j)
 	{
-		var uAngle = BUILDING_ANGlE - PI * (2-j) / 2;
+		var uAngle = BUILDING_ORIENTATION - PI * (2-j) / 2;
 		var count = (startEntities[j].Count !== undefined ? startEntities[j].Count : 1);
 		for (var numberofentities = 0; numberofentities < count; numberofentities++)
 		{
@@ -115,7 +111,7 @@
 		}
 	}
 	// create resources
-	var bbAngle = BUILDING_ANGlE;
+	var bbAngle = BUILDING_ORIENTATION;
 	var bbDist = 10;
 	var bbX = round(playerX[i] + bbDist * cos(bbAngle));
 	var bbZ = round(playerZ[i] + bbDist * sin(bbAngle));
@@ -191,7 +187,7 @@
 			"cornerIn", "wallLong", "house", "tower", "wallLong", "tower", "wallLong",
 			"cornerIn", "wallLong", "house", "tower"];
 	}
-	placeCustomFortress(playerX[i], playerZ[i], new Fortress("Spahbod", wall), civ, i+1, BUILDING_ANGlE);
+	placeCustomFortress(playerX[i], playerZ[i], new Fortress("Spahbod", wall), civ, i+1);
 }
 
 // create lakes
Index: binaries/data/mods/public/maps/random/gear.js
===================================================================
--- binaries/data/mods/public/maps/random/gear.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/gear.js	(working copy)
@@ -48,11 +48,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -156,7 +152,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/guadalquivir_river.js
===================================================================
--- binaries/data/mods/public/maps/random/guadalquivir_river.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/guadalquivir_river.js	(working copy)
@@ -43,10 +43,7 @@
 
 const pForestP = [tForestFloorP + TERRAIN_SEPARATOR + oPoplar, tForestFloorP];
 const pForestC = [tForestFloorC + TERRAIN_SEPARATOR + oCarob, tForestFloorC];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -152,7 +149,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : false});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': false });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/gulf_of_bothnia.js
===================================================================
--- binaries/data/mods/public/maps/random/gulf_of_bothnia.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/gulf_of_bothnia.js	(working copy)
@@ -121,10 +121,7 @@
 }
 
 const pForest = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -209,7 +206,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/hyrcanian_shores.js
===================================================================
--- binaries/data/mods/public/maps/random/hyrcanian_shores.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/hyrcanian_shores.js	(working copy)
@@ -47,10 +47,6 @@
 
 const WATER_WIDTH = 0.25;
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -128,7 +124,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/island_stronghold.js
===================================================================
--- binaries/data/mods/public/maps/random/island_stronghold.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/island_stronghold.js	(working copy)
@@ -59,7 +59,6 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
 log("Initializing map...");
 InitMap();
@@ -166,7 +165,7 @@
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 
 		// create starting units
-		placeCivDefaultEntities(fx, fz, teams[i][p], BUILDING_ANGlE, { "iberWall": false });
+		placeCivDefaultEntities(fx, fz, teams[i][p], { "iberWall": false });
 	}
 
 	log("Create initial mines for team " + i);
Index: binaries/data/mods/public/maps/random/islands.js
===================================================================
--- binaries/data/mods/public/maps/random/islands.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/islands.js	(working copy)
@@ -48,10 +48,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -124,7 +121,7 @@
 	createArea(placer, [terrainPainter, elevationPainter, paintClass(clPlayer)], null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/kerala.js
===================================================================
--- binaries/data/mods/public/maps/random/kerala.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/kerala.js	(working copy)
@@ -34,10 +34,7 @@
 
 const pForestD = [tForestFloor + TERRAIN_SEPARATOR + oTree, tForestFloor];
 const pForestP = [tForestFloor + TERRAIN_SEPARATOR + oPalm, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -112,7 +109,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 		// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/lake.js
===================================================================
--- binaries/data/mods/public/maps/random/lake.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/lake.js	(working copy)
@@ -46,10 +46,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -125,7 +122,7 @@
 	addToClass(ix, iz-5, clPlayer);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/latium.js
===================================================================
--- binaries/data/mods/public/maps/random/latium.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/latium.js	(working copy)
@@ -63,10 +63,6 @@
 const pPoplarForest = [tForestFloor+TERRAIN_SEPARATOR+oLombardyPoplar, tGrass];
 const pMainForest = [tForestFloor+TERRAIN_SEPARATOR+oCarob, tForestFloor+TERRAIN_SEPARATOR+oBeech, tGrass, tGrass];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -431,7 +427,7 @@
 	createArea(placer, [painter, elevationPainter], null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/lorraine_plain.js
===================================================================
--- binaries/data/mods/public/maps/random/lorraine_plain.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/lorraine_plain.js	(working copy)
@@ -42,10 +42,7 @@
 const pForestB = [tGrassDForest + TERRAIN_SEPARATOR + oBeech, tGrassDForest];
 const pForestO = [tGrassPForest + TERRAIN_SEPARATOR + oOak, tGrassPForest];
 const pForestR = [tGrassDForest + TERRAIN_SEPARATOR + oBeech, tGrassDForest, tGrassDForest + TERRAIN_SEPARATOR + oOak, tGrassDForest, tGrassDForest, tGrassDForest];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -133,7 +130,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/mainland.js
===================================================================
--- binaries/data/mods/public/maps/random/mainland.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/mainland.js	(working copy)
@@ -46,10 +46,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -125,7 +122,7 @@
 	addToClass(ix, iz-5, clPlayer);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create the city patch
 	var cityRadius = radius/3;
Index: binaries/data/mods/public/maps/random/migration.js
===================================================================
--- binaries/data/mods/public/maps/random/migration.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/migration.js	(working copy)
@@ -47,10 +47,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -132,7 +129,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : false});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': false });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/neareastern_badlands.js
===================================================================
--- binaries/data/mods/public/maps/random/neareastern_badlands.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/neareastern_badlands.js	(working copy)
@@ -43,10 +43,6 @@
 const pForest = [tForestFloor + TERRAIN_SEPARATOR + oDatePalm, tForestFloor + TERRAIN_SEPARATOR + oSDatePalm, tForestFloor];
 const pForestOasis = [tGrass + TERRAIN_SEPARATOR + oDatePalm, tGrass + TERRAIN_SEPARATOR + oSDatePalm, tGrass];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -119,7 +115,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/new_rms_test.js
===================================================================
--- binaries/data/mods/public/maps/random/new_rms_test.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/new_rms_test.js	(working copy)
@@ -1,9 +1,5 @@
 RMS.LoadLibrary("rmgen");
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -56,7 +52,7 @@
 	var iz = round(fz);
 
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 }
 
 
Index: binaries/data/mods/public/maps/random/northern_lights.js
===================================================================
--- binaries/data/mods/public/maps/random/northern_lights.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/northern_lights.js	(working copy)
@@ -29,10 +29,7 @@
 
 const pForestD = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor, tForestFloor];
 const pForestS = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor, tForestFloor, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -107,7 +104,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create metal mine
 	var bbAngle = randFloat(0, TWO_PI);
Index: binaries/data/mods/public/maps/random/oasis.js
===================================================================
--- binaries/data/mods/public/maps/random/oasis.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/oasis.js	(working copy)
@@ -39,10 +39,7 @@
 const pForestMain = [tForestFloor + TERRAIN_SEPARATOR + ePalmShort, tForestFloor + TERRAIN_SEPARATOR + ePalmTall, tForestFloor];
 const pOasisForestLight = [tForestFloor + TERRAIN_SEPARATOR + ePalmShort, tForestFloor + TERRAIN_SEPARATOR + ePalmTall, tForestFloor,tForestFloor,tForestFloor
 					,tForestFloor,tForestFloor,tForestFloor,tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -126,7 +123,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 		
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/persian_highlands.js
===================================================================
--- binaries/data/mods/public/maps/random/persian_highlands.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/persian_highlands.js	(working copy)
@@ -54,8 +54,6 @@
 // terrain + entity (for painting)
 const pForestO = [tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor, tDirtMain, tDirtMain];
 
-const BUILDING_ANGlE = -PI/4;
-
 log("Initializing map...");
 
 InitMap();
@@ -136,7 +134,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/pheonician_levant.js
===================================================================
--- binaries/data/mods/public/maps/random/pheonician_levant.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/pheonician_levant.js	(working copy)
@@ -44,8 +44,6 @@
 // terrain + entity (for painting)
 const pForest = [tForestFloor + TERRAIN_SEPARATOR + oDatePalm, tForestFloor + TERRAIN_SEPARATOR + oSDatePalm, tForestFloor + TERRAIN_SEPARATOR + oCarob, tForestFloor, tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
 log("Initializing map...");
 
 InitMap();
@@ -118,7 +116,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/pyrenean_sierra.js
===================================================================
--- binaries/data/mods/public/maps/random/pyrenean_sierra.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/pyrenean_sierra.js	(working copy)
@@ -242,10 +242,7 @@
 						tForestTransition,tGrassLandForest2,tForestTransition,tForestTransition,tForestTransition,
 						tGrassLandForest,tForestTransition,tGrassLandForest2,tForestTransition,
 						tGrassLandForest2,tGrassLandForest2,tGrassLandForest2,tGrassLandForest2];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -351,7 +348,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/rhine_marshlands.js
===================================================================
--- binaries/data/mods/public/maps/random/rhine_marshlands.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/rhine_marshlands.js	(working copy)
@@ -37,10 +37,7 @@
 
 const pForestD = [tForestFloor + TERRAIN_SEPARATOR + oBeech, tForestFloor];
 const pForestP = [tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -113,7 +110,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/rivers.js
===================================================================
--- binaries/data/mods/public/maps/random/rivers.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/rivers.js	(working copy)
@@ -50,10 +50,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -154,7 +151,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/rmgen/library.js
===================================================================
--- binaries/data/mods/public/maps/random/rmgen/library.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/rmgen/library.js	(working copy)
@@ -13,6 +13,8 @@
 const MAX_HEIGHT_RANGE = 0xFFFF / HEIGHT_UNITS_PER_METRE // Engine limit, Roughly 700 meters
 const MIN_HEIGHT = - SEA_LEVEL;
 const MAX_HEIGHT = MAX_HEIGHT_RANGE - SEA_LEVEL;
+// Default angle for buildings
+const BUILDING_ORIENTATION = - PI / 4;
 
 function fractionToTiles(f)
 {
Index: binaries/data/mods/public/maps/random/saharan_oases.js
===================================================================
--- binaries/data/mods/public/maps/random/saharan_oases.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/saharan_oases.js	(working copy)
@@ -47,8 +47,6 @@
 // terrain + entity (for painting)
 const pForest = [tLush + TERRAIN_SEPARATOR + oDatePalm, tLush + TERRAIN_SEPARATOR + oSDatePalm, tLush];
 
-const BUILDING_ANGlE = -PI/4;
-
 log("Initializing map...");
 
 InitMap();
@@ -118,7 +116,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/sahel.js
===================================================================
--- binaries/data/mods/public/maps/random/sahel.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/sahel.js	(working copy)
@@ -52,10 +52,6 @@
 	}
 }
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -121,7 +117,7 @@
 	addToClass(ix, iz-5, clPlayer);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/sahel_watering_holes.js
===================================================================
--- binaries/data/mods/public/maps/random/sahel_watering_holes.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/sahel_watering_holes.js	(working copy)
@@ -40,10 +40,7 @@
 const aBushSmall = "actor|props/flora/bush_dry_a.xml";
 
 const pForest = [tForestFloor + TERRAIN_SEPARATOR + oBaobab, tForestFloor + TERRAIN_SEPARATOR + oBaobab, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -116,7 +113,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/schwarzwald.js
===================================================================
--- binaries/data/mods/public/maps/random/schwarzwald.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/schwarzwald.js	(working copy)
@@ -109,8 +109,6 @@
 var tWater = ['dirt_brown_d'];
 var tWaterBorder = ['dirt_brown_d'];
 
-const BUILDING_ANGlE = -PI/4;
-
 // Setup map 
 var mapSize = getMapSize();
 var mapRadius = mapSize/2;
@@ -242,7 +240,7 @@
 
 	rectangularSmoothToHeight([x,z] , 20, 20, playerHeight, 0.8);
 
-	placeCivDefaultEntities(x, z, i+1, BUILDING_ANGlE, {'iberWall': false});
+	placeCivDefaultEntities(x, z, i+1, { 'iberWall': false });
 	
 	// Place base texture
 	var placer = new ClumpPlacer(2*baseRadius*baseRadius, 2/3, 1/8, 10, x, z);
Index: binaries/data/mods/public/maps/random/snowflake_searocks.js
===================================================================
--- binaries/data/mods/public/maps/random/snowflake_searocks.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/snowflake_searocks.js	(working copy)
@@ -46,11 +46,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -1555,7 +1551,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/survivalofthefittest.js
===================================================================
--- binaries/data/mods/public/maps/random/survivalofthefittest.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/survivalofthefittest.js	(working copy)
@@ -49,10 +49,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -163,8 +160,8 @@
 	// Place default civ starting entities
 	var uDist = 6;
 	var uSpace = 2;
-	placeObject(fx, fz, "skirmish/structures/default_civil_centre", id, BUILDING_ANGlE);
-	var uAngle = BUILDING_ANGlE - PI / 2;
+	placeObject(fx, fz, "skirmish/structures/default_civil_centre", id, BUILDING_ORIENTATION);
+	var uAngle = BUILDING_ORIENTATION - PI / 2;
 	var count = 4;
 	for (var numberofentities = 0; numberofentities < count; numberofentities++)
 	{
Index: binaries/data/mods/public/maps/random/syria.js
===================================================================
--- binaries/data/mods/public/maps/random/syria.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/syria.js	(working copy)
@@ -40,11 +40,7 @@
 
 const pForestP = [tForestFloor2 + TERRAIN_SEPARATOR + oPalm, tForestFloor2];
 const pForestT = [tForestFloor1 + TERRAIN_SEPARATOR + oTamarix,tForestFloor2];
-const BUILDING_ANGlE = -PI/4;
 
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -122,7 +118,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/the_nile.js
===================================================================
--- binaries/data/mods/public/maps/random/the_nile.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/the_nile.js	(working copy)
@@ -49,8 +49,6 @@
 var pForest = [tForestFloor + TERRAIN_SEPARATOR + oDatePalm, tForestFloor + TERRAIN_SEPARATOR + oSDatePalm, tForestFloor];
 var pForestOasis = [tGrass + TERRAIN_SEPARATOR + oDatePalm, tGrass + TERRAIN_SEPARATOR + oSDatePalm, tGrass];
 
-const BUILDING_ANGlE = -PI/4;
-
 log("Initializing map...");
 
 InitMap();
@@ -144,7 +142,7 @@
 	createArea(placer, painter, null);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/unknown.js
===================================================================
--- binaries/data/mods/public/maps/random/unknown.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/unknown.js	(working copy)
@@ -48,10 +48,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -1668,9 +1665,9 @@
 	
 	// create starting units
 	if (iberianTowers)
-		placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
+		placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
 	else
-		placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+		placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/unknown_land.js
===================================================================
--- binaries/data/mods/public/maps/random/unknown_land.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/unknown_land.js	(working copy)
@@ -48,10 +48,7 @@
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -1440,7 +1437,7 @@
 	var iz = round(fz);
 	
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 	
 	// create animals
 	for (var j = 0; j < 2; ++j)
Index: binaries/data/mods/public/maps/random/unknown_nomad.js
===================================================================
--- binaries/data/mods/public/maps/random/unknown_nomad.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/unknown_nomad.js	(working copy)
@@ -48,10 +48,7 @@
 
 var pForestD = [tGrassDForest + TERRAIN_SEPARATOR + oOak, tGrassDForest + TERRAIN_SEPARATOR + oOakLarge, tGrassDForest];
 var pForestP = [tGrassPForest + TERRAIN_SEPARATOR + oPine, tGrassPForest + TERRAIN_SEPARATOR + oAleppoPine, tGrassPForest];
-const BUILDING_ANGlE = -PI/4;
 
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
Index: binaries/data/mods/public/maps/random/volcanic_lands.js
===================================================================
--- binaries/data/mods/public/maps/random/volcanic_lands.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/volcanic_lands.js	(working copy)
@@ -24,7 +24,6 @@
 
 var pForestD = [tGrassC + TERRAIN_SEPARATOR + oTree, tGrassC];
 var pForestP = [tGrassB + TERRAIN_SEPARATOR + oTree, tGrassB];
-const BUILDING_ANGlE = -PI/4;
 
 log("Initializing map...");
 InitMap();
@@ -90,7 +89,7 @@
 	createArea(placer, painter, null);
 
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
+	placeCivDefaultEntities(fx, fz, id);
 
 	// create metal mine
 	var bbAngle = randFloat(0, TWO_PI);

Index: binaries/data/mods/public/maps/random/rmgen/misc.js
===================================================================
--- binaries/data/mods/public/maps/random/rmgen/misc.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/rmgen/misc.js	(working copy)
@@ -136,17 +136,17 @@
 //	fx&fz: position of player base
 //	playerid: id of player
 //	civEntities: use getStartingEntities(id-1) fo this one
 //	BUILDING_ANGlE: angle of main base building
 //
 ///////////////////////////////////////////////////////////////////////////////////////////
-function createStartingPlayerEntities(fx, fz, playerid, civEntities, BUILDING_ANGlE)
+function createStartingPlayerEntities(fx, fz, playerid, civEntities, orientation = BUILDING_ORIENTATION)
 {
 	var uDist = 6;
 	var uSpace = 2;
-	placeObject(fx, fz, civEntities[0].Template, playerid, BUILDING_ANGlE);
+	placeObject(fx, fz, civEntities[0].Template, playerid, orientation);
 	for (var j = 1; j < civEntities.length; ++j)
 	{
-		var uAngle = BUILDING_ANGlE - PI * (2-j) / 2;
+		var uAngle = orientation - PI * (2-j) / 2;
 		var count = (civEntities[j].Count !== undefined ? civEntities[j].Count : 1);
 		for (var numberofentities = 0; numberofentities < count; numberofentities++)
 		{
@@ -163,12 +163,12 @@
 //	Creates the default starting player entities depending on the players civ
 //	fx&fy: position of player base
 //	playerid: id of player
-//	angle: angle of main base building, optional, default is BUILDING_ANGlE
 //	kwargs: Takes some optional keyword arguments to tweek things
 //		'iberWall': may be false, 'walls' (default) or 'towers'. Determines the defensive structures Iberians get as civ bonus
+//		'orientation': angle of the main base building, default is BUILDING_ORIENTATION
 //
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-function placeCivDefaultEntities(fx, fz, playerid, angle, kwargs)
+function placeCivDefaultEntities(fx, fz, playerid, kwargs = {})
 {
 	// Unpack kwargs
 	kwargs = (kwargs || {});
@@ -177,15 +177,18 @@
 		iberWall = false;
 	if ('iberWall' in kwargs)
 		iberWall = kwargs['iberWall'];
+	var orientation = BUILDING_ORIENTATION
+	if ('orientation' in kwargs)
+		orientation = kwargs['orientation'];
 	// Place default civ starting entities
 	var civ = getCivCode(playerid-1);
 	var civEntities = getStartingEntities(playerid-1);
 	var uDist = 6;
 	var uSpace = 2;
-	placeObject(fx, fz, civEntities[0].Template, playerid, angle);
+	placeObject(fx, fz, civEntities[0].Template, playerid, orientation);
 	for (var j = 1; j < civEntities.length; ++j)
 	{
-		var uAngle = angle - PI * (2-j) / 2;
+		var uAngle = orientation - PI * (2-j) / 2;
 		var count = (civEntities[j].Count !== undefined ? civEntities[j].Count : 1);
 		for (var numberofentities = 0; numberofentities < count; numberofentities++)
 		{
@@ -198,7 +201,7 @@
 	if (civ == 'iber' && iberWall != false)
 	{
 		if (iberWall == 'towers')
-			placePolygonalWall(fx, fz, 15, ['entry'], 'tower', civ, playerid, angle, 7);
+			placePolygonalWall(fx, fz, 15, ['entry'], 'tower', civ, playerid, orientation, 7);
 		else
 			placeGenericFortress(fx, fz, 20/*radius*/, playerid);
 	}
@@ -136,17 +136,17 @@
 //	playerid: id of player
 //	civEntities: use getStartingEntities(id-1) fo this one
-//	BUILDING_ANGlE: angle of main base building
+//	orientation: orientation of the main base building, default is BUILDING_ORIENTATION
 //
 ///////////////////////////////////////////////////////////////////////////////////////////
Index: binaries/data/mods/public/maps/random/rmgen/wall_builder.js
===================================================================
--- binaries/data/mods/public/maps/random/rmgen/wall_builder.js	(revision 18141)
+++ binaries/data/mods/public/maps/random/rmgen/wall_builder.js	(working copy)
@@ -470,13 +470,12 @@
 //	fortress       An instance of Fortress with a wall defined
 //	style          Optional. Wall style string. Default is the civ of the given player, "palisades" for gaia
 //	playerId       Optional. Number of the player the wall will be placed for. Default is 0 (gaia)
 //	orientation    Optional. Angle the first wall element (should be a gate or entrance) is placed. Default is 0
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-function placeCustomFortress(centerX, centerY, fortress, style, playerId, orientation)
+function placeCustomFortress(centerX, centerY, fortress, style, playerId = 0, orientation = BUILDING_ORIENTATION)
 {
 	// Graciously handle arguments
 	fortress = (fortress || fortressTypes["medium"]);
-	playerId = (playerId || 0);
 	if (!wallStyles.hasOwnProperty(style))
 	{
 		if (playerId == 0)
@@ -484,7 +483,6 @@
 		else
 			style = (getCivCode(playerId-1));
 	}
-	orientation = (orientation || 0);
 	
 	// Calculate center if fortress.centerToFirstElement is undefined (default)
 	var centerToFirstElement = fortress.centerToFirstElement;
@@ -470,13 +470,12 @@
 //	style          Optional. Wall style string. Default is the civ of the given player, "palisades" for gaia
 //	playerId       Optional. Number of the player the wall will be placed for. Default is 0 (gaia)
-//	orientation    Optional. Angle the first wall element (should be a gate or entrance) is placed. Default is 0
+//	orientation    Optional. Angle the first wall element (should be a gate or entrance) is placed. Default is BUILDING_ORIENTATION
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////